@@ -4,6 +4,8 @@ from .CustomKernel import Stream
 from .ComputeProductCUDA import ComputeProductCUDA
 from .GetAddressOfIDCUDA import GetAddressOfIDCUDA
 from .GetDivOfAddressCUDA import GetDivOfAddressCUDA
+from .GetDivOfAddressV2CUDA import GetDivOfAddressV2CUDA
 from .GetIOACUDA import GetIOACUDA
 from .GetWriteAddressCUDA import GetWriteAddressCUDA
+from .GetWriteAddressV2CUDA import GetWriteAddressV2CUDA
 from .PQDecodeCUDA import PQDecodeCUDA
\ No newline at end of file
