@@ -6,8 +6,9 @@ from time import time
 
 from .kernels import MaxSimCUDA
 from .kernels import ComputeCentroidsCUDA
+from ..CustomModule import CustomModule
 
-class MultiKMeans(nn.Module):
+class MultiKMeans(CustomModule):
   """
   Run multiple independent K-means algorithms in parallel.
   Parameters:
@@ -117,6 +118,10 @@ class MultiKMeans(nn.Module):
     diff.pow_(2)
     return diff.sum()
 
+  @staticmethod
+  def calculate_inertia(a):
+    return (-a).mean()
+
   @staticmethod
   def cos_sim(a, b, normalize=True, inplace=False):
     """
@@ -376,7 +381,7 @@ class MultiKMeans(nn.Module):
         new_centroids = self.compute_centroids(data, labels)
         error = self.calculate_error(centroids, new_centroids)
         centroids = new_centroids
-        inertia = torch.sum(1-maxsims)
+        inertia = self.calculate_inertia(maxsims)
         if self.verbose >= 3:
           print(f"----iteration {j} of {i}th redo, error={error.item()}, inertia={inertia.item()}")
         if error <= self.tol:
